"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_joyride_1 = __importStar(require("react-joyride"));
class IntroductionTour extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.handleJoyrideCallback = (data) => {
            const { index, type, status } = data;
            if ([react_joyride_1.STATUS.FINISHED, react_joyride_1.STATUS.SKIPPED].includes(status)) {
                // If tour is finished or skipped, turn off runTour and reset indexes
                this.props.setTourInfo(false, 0);
                return;
            }
            if ([react_joyride_1.EVENTS.STEP_AFTER, react_joyride_1.EVENTS.TARGET_NOT_FOUND].includes(type)) {
                let newStepIndex = 0;
                if (index === 0) {
                    // If we're on step 0 and a button is pressed, advanced to step 1
                    newStepIndex = 1;
                    this.setState({ stepIndex: newStepIndex });
                }
                else if (index === 3) {
                    newStepIndex = 4;
                    setTimeout(() => {
                        this.setState({ stepIndex: newStepIndex });
                    }, 400);
                }
                else if (index === 1 || index === 2) {
                    // Just for debugging
                    console.log('import modal is not open');
                }
                // Register tour step index with Mito state
                this.props.setTourInfo(true, newStepIndex);
            }
        };
        /*
            We add step advancement logic here to create a controlled tour which updates when the user
            updates the state of Mito. For example, when the user opens the import modal, we go to the next step.

            We are able to add this logic here, by using a key at the instantiation of the IntroductionTour which
            updates each time this logic should trigger.
        */
        let currentStepIndex = props.stepIndex;
        if (props.stepIndex === 1 && props.isImportModalOpen) {
            currentStepIndex = 2;
        }
        else if (props.stepIndex === 2 && !props.isImportModalOpen) {
            currentStepIndex = 3;
        }
        // Register with the backend
        this.props.setTourInfo(true, currentStepIndex);
        this.state = {
            isImportModalOpen: props.isImportModalOpen,
            stepIndex: currentStepIndex,
            steps: [
                {
                    // Step 0 
                    title: 'Welcome to Mito!',
                    content: react_1.default.createElement("p", null, "Do you want to take a short tour? I'll show you how to load some data into Mito."),
                    placement: 'center',
                    target: 'body',
                },
                {
                    // Step 1
                    content: react_1.default.createElement("p", null, "Import data to start your analysis."),
                    placement: 'right',
                    target: '#tour-import-button-id',
                    hideFooter: true,
                },
                {
                    // Step 2
                    title: 'Importing Data',
                    content: react_1.default.createElement("p", null,
                        "Click the ",
                        react_1.default.createElement("b", null, "Add File"),
                        " button, ",
                        react_1.default.createElement("b", null, "select a csv"),
                        " from the dropdown, and then press ",
                        react_1.default.createElement("b", null, "import.")),
                    placement: 'left',
                    target: '.modal',
                    hideFooter: true,
                },
                {
                    // Step 3
                    title: react_1.default.createElement("p", null, "\uD83C\uDF89 Congrats! \uD83C\uDF89"),
                    content: (react_1.default.createElement("div", null,
                        react_1.default.createElement("p", null, "You've uploaded data to Mito. You're now ready to start automating your analyses. "),
                        react_1.default.createElement("br", null),
                        react_1.default.createElement("p", null, "Edit your data by writing formulas, sorting, filtering, and creating pivot tables."))),
                    placement: 'top',
                    target: '.ag-center-cols-viewport',
                },
            ]
        };
        this.handleJoyrideCallback = this.handleJoyrideCallback.bind(this);
    }
    render() {
        return (react_1.default.createElement(react_joyride_1.default, { run: this.props.run, steps: this.state.steps, stepIndex: this.state.stepIndex, continuous: true, showProgress: true, showSkipButton: true, disableScrolling: true, locale: { back: 'Back', last: 'Last', next: 'Next', skip: 'Skip' }, spotlightClicks: true, callback: this.handleJoyrideCallback, styles: {
                options: {
                    primaryColor: '#0081DE',
                    textColor: '#343434',
                }
            } }));
    }
}
exports.default = IntroductionTour;
//# sourceMappingURL=IntroductionTour.js.map